==> haskell-wai-cors-0.2.7-440-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-UdEIerj4JC56dZHPKg7Na
key:                  wai-cors-0.2.7-UdEIerj4JC56dZHPKg7Na
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  4e93f27f38f7c708572436ff1034aac4
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-cors
hs-libraries:         HSwai-cors-0.2.7-UdEIerj4JC56dZHPKg7Na
depends:
    attoparsec-0.14.4-H9Y4iLHDqcP1CPr5BByOUl base-4.17.2.1
    base-unicode-symbols-0.2.4.2-DGP2ohBQv5PB4jg5C9PUqH
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-L5gSnJGPP5IIfg5Ct42zAo
    http-types-0.12.4-J468GPAKalzFHPyn7Dxh3c mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.4-9Kksr2P6n2618XIJvAeWn8

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.7-441-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 wai-cors
version:              0.2.7
visibility:           public
id:                   wai-cors-0.2.7-DbSV6gjVc1qCE4NhpqdKqO
key:                  wai-cors-0.2.7-DbSV6gjVc1qCE4NhpqdKqO
license:              MIT
copyright:
    (c) 2015-2019 Lars Kuhtz <lakuhtz@gmail.com>,
    (c) 2014 AlephCloud Systems, Inc.

maintainer:           Lars Kuhtz <lakuhtz@gmail.com>
author:               Lars Kuhtz <lakuhtz@gmail.com>
homepage:             https://github.com/larskuhtz/wai-cors
synopsis:             CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.

category:             HTTP, Network, Web, Wai
abi:                  853dc8af6cc08f460250133d6cce9206
exposed:              True
exposed-modules:      Network.Wai.Middleware.Cors
import-dirs:          /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/wai-cors-0.2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-cors
hs-libraries:         HSwai-cors-0.2.7-DbSV6gjVc1qCE4NhpqdKqO
depends:
    attoparsec-0.14.4-7XWZ3nsZOGKJDEorzXp6qF base-4.17.2.1
    base-unicode-symbols-0.2.4.2-DGP2ohBQv5PB4jg5C9PUqH
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-GKEaqjX3nXNEZmMRebSTRD
    http-types-0.12.4-JotGc98QwUtHuX8PPdlxoe mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.4-Jw3By0RvhPE8QsBvrL71Dx

haddock-interfaces:   /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html:         /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
